==> 3.1.0.tar.gz: lib/src/api_services.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:developer';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:http/http.dart' as http;
import './Constant/constant.dart' as constant;import 'Constant/constant.dart';
import 'blocs/pay_unit_stream.dart';

class ApiService {

  initiatePayment({
    required transaction_id,
    required String transactionAmount,
    required String currency,
    required String transactionCallBackUrl,
    required context,
    required String X_API_KEY,
    required String productName,
    required String description,
    required merchandUserName,
    required merchandPassword,
    required mode,
    required Function actionAfterProccess,
  }) async {
    try {
      progressHub("Please wait", context);
      var data = jsonEncode({
        "currency": currency,
        "transaction_id": transaction_id,
        "total_amount": transactionAmount,
        "return_url": ""
      });
      var jsonResponse;
      var url = Uri.parse("${constant.baseUrl}/gateway/initialize");
      var response = await http.post(url,
          body: data,
          headers: getGlobalHeader(
              X_API_KEY, "$merchandUserName:$merchandPassword", mode));
      jsonResponse = json.decode(response.body);
      if (response.statusCode == 200 || response.statusCode == 201) {
        print("This is /initiatePayment response : $jsonResponse");
        if (jsonResponse != null) {
          List result = await getAllProviders(
            context: context,
            transactionId: jsonResponse['data']['t_id'],
            transactionAmount: jsonResponse['data']['t_sum'],
            transactionCallBackUrl: jsonResponse['data']['t_url'],
            merchandPassword: merchandPassword,
            merchandUserName: merchandUserName,
            X_API_KEY: X_API_KEY,
            mode: mode,
            actionAfterProccess: actionAfterProccess,
          );
          Navigator.of(context).pop();

          return {"result": result, "transaction_id": transaction_id};
        }
      } else {
        Navigator.of(context).pop();
        print("Response : $jsonResponse");
        if (jsonResponse['message'] == null) {
          constant.makeToast(jsonResponse['error'], context, Colors.red);
        } else {
          constant.makeToast(jsonResponse['message'], context, Colors.red);
        }
        actionAfterProccess(transaction_id, "FAILED");
        return false;
      }
    } catch (e) {
      print("Error : $e");
      Navigator.of(context).pop();
      showInfoDialog(
          context, "Something went wrong , please try again or later");
      actionAfterProccess(transaction_id, "FAILED");

      return false;
    }
  }

  getAllProviders({
    context,
    required String transactionId,
    required String transactionAmount,
    required String transactionCallBackUrl,
    required String merchandUserName,
    required String merchandPassword,
    required String X_API_KEY,
    required String mode,
    required Function actionAfterProccess,
  }) async {
    try {
      var jsonResponse;
      var url = Uri.parse(
          "${constant.baseUrl}/gateway/gateways?t_id=$transactionId&t_sum=$transactionAmount&t_url=$transactionCallBackUrl");
      var response = await http.get(url,
          headers: getGlobalHeader(
              X_API_KEY, "$merchandUserName:$merchandPassword", mode));
      jsonResponse = json.decode(response.body);
      if (response.statusCode == 200) {
        print("This is /getAllProviders response : $jsonResponse");
        if (jsonResponse != null) {
          return json.decode(response.body)['data'];
        }
      } else {
        if (jsonResponse != null) {
          print("Response :  : $jsonResponse");
          Navigator.of(context).pop();
          actionAfterProccess(transactionId, "FAILED");
          return [];
        }
      }
    } catch (e) {
      print("Error : $e");
      Navigator.of(context).pop();
      actionAfterProccess(transactionId, "FAILED");
      showInfoDialog(
          context, "Something went wrong , please try again or later");
    }
  }

  makePayment({
    required context,
    required String X_API_KEY,
    required String transactionAmount,
    required String transactionCallBackUrl,
    required String provider_short_tag,
    required String? phoneNumber,
    required Function actionAfterProccess,
    required String userName,
    required merchandUserName,
    required transaction_id,
    required merchandPassword,
    required mode,
    required currency,
    required paymentType,
  }) async {
    var response;
    var data = currency != null
        ? jsonEncode({
      'gateway': provider_short_tag,
      'amount': int.parse(transactionAmount),
      'transaction_id': transaction_id,
      'return_url': transactionCallBackUrl,
      'phone_number': phoneNumber,
      "name": userName,
      "currency": currency,
      "paymentType": paymentType
    })
        : jsonEncode({
      'gateway': provider_short_tag,
      'amount': int.parse(transactionAmount),
      'transaction_id': transaction_id,
      'return_url': transactionCallBackUrl,
      'phone_number': phoneNumber,
      "name": userName,
      "paymentType": paymentType
    });
    try {
      progressHub("Please wait", context);
      print("##A");

      var jsonResponse;
      var url = Uri.parse("${constant.baseUrl}/gateway/makepayment");
      response = await http.post(url,
          body: data,
          headers: getGlobalHeader(
              X_API_KEY, "$merchandUserName:$merchandPassword", mode));
      print("## ${response.body}");

      if (response.statusCode == 200 || response.statusCode == 201) {
        constant.makeToast(json.decode(response.body)['message'], context, Colors.green);
        jsonResponse = json.decode(response.body)["data"];
        if (jsonResponse["access_token"] != null) {
          print("Response #1 : $jsonResponse");
          String orderId = jsonResponse["order_id"];
          Map obj = {
            "order_id": orderId,
            "amount": jsonResponse["amount"],
            "currency": jsonResponse["currency"],
            "client_id": jsonResponse["client_id"],
            "accessToken": jsonResponse["access_token"],
          };
          Navigator.pop(context);
          return obj;
        } else {
          print("Response #2 : $jsonResponse");
          var obj = {
            "order_id": jsonResponse["order_id"],
            "amount": jsonResponse["amount"],
            "currency": jsonResponse["currency"],
            "client_id": jsonResponse["client_id"],
          };
          getPaymentStatus(
              transactionId: transaction_id,
              paymentRef: jsonResponse["payment_ref"],
              payToken: jsonResponse["pay_token"],
              merchandUserName: merchandUserName,
              merchandPassword: merchandPassword,
              provider_short_tag: provider_short_tag,
              actionAfterProccess: actionAfterProccess,
              context: context,
              mode: mode,
              X_API_KEY: X_API_KEY);
          return obj;
        }
      } else {
        var responseData = json.decode(response.body);
        Navigator.of(context).pop();
        actionAfterProccess(transaction_id, "FAILED");
        if (responseData != null) {
          payUnitStream.paymentSink.addError("Error");
          Navigator.of(context).pop();
          constant.makeToast(responseData['message'], context, Colors.red);
        }
      }
    } catch (e) {
      Navigator.of(context).pop();
      Navigator.of(context).pop();
      actionAfterProccess(transaction_id, "FAILED");
    }
  }

  getPaymentStatus({
    required context,
    required String transactionId,
    required String paymentRef,
    required String payToken,
    required String merchandUserName,
    required String merchandPassword,
    required String provider_short_tag,
    required Function actionAfterProccess,
    required String X_API_KEY,
    required String mode,
  }) async {
    try {
      const time = const Duration(seconds: 4);
      Timer.periodic(time, (Timer timer) async {
        var jsonResponse;
        var url = Uri.parse(
            "${constant.baseUrl}/gateway/paymentstatus/$provider_short_tag/$transactionId?payment_ref=${paymentRef}&pay_token=${payToken}");
        log(url.toString());
        var response = await http.get(url,
            headers: getGlobalHeader(
                X_API_KEY, "$merchandUserName:$merchandPassword", mode));
        print("This is response status/; ${response.statusCode}");
        print("This is response Mode/; $mode");
        jsonResponse = await jsonDecode(response.body);
        print("This is response status/; $jsonResponse");

        if (jsonResponse['status'] == "SUCCESSFUL") {
          print("Response SUCCESSFUL: $jsonResponse");
          Navigator.pop(context);
          actionAfterProccess(transactionId, "SUCCESS");
          timer.cancel();
        }

        if (jsonResponse['status'] == "FAILED") {
          Navigator.pop(context);
          print("Response FAILED: $jsonResponse");
          actionAfterProccess(transactionId, "FAILED");
          timer.cancel();
        }
      });
    } catch (e) {
      // Navigator.pop(context);
      actionAfterProccess(transactionId, "FAILED");
      showInfoDialog(
          context, "Something went wrong , please try again or later");
    }
  }

  progressHub(msg, context) {
    showDialog(
      barrierDismissible: false,
      barrierColor: Colors.black.withOpacity(0.5),
      context: context,
      builder: (context) => WillPopScope(
        onWillPop: () async {
          return false;
        },
        child: AlertDialog(
          shape:
          RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
          backgroundColor: Colors.white.withOpacity(0.9),
          content: SizedBox(
            height: 200.0,
            child: SpinKitSquareCircle(
              color: payUnitGreenColor,
              size: 50.0,
            ),
          ),
        ),
      ),
    );
  }

  closeDialog(context) {
    // NativeProgressHud.hideWaiting();
    Navigator.of(context).pop();
    // Navigator.of(context).pop();
  }
}

==> 3.1.3.tar.gz: lib/src/api_services.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:http/http.dart' as http;
import './constant/constant.dart' as constant;
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'constant/constant.dart';
import 'blocs/pay_unit_stream.dart';

class ApiService {
  final localNotificationsPlugin = FlutterLocalNotificationsPlugin();

  initiatePayment({
    required transactionId,
    required String transactionAmount,
    required String currency,
    required String transactionCallBackUrl,
    required context,
    required String xApiKey,
    required String productName,
    required String description,
    required merchandUserName,
    required merchandPassword,
    required mode,
    required Function actionAfterProccess,
  }) async {
    try {
      progressHub("Please wait", context);
      var data = jsonEncode({
        "currency": currency,
        "transaction_id": transactionId,
        "total_amount": transactionAmount,
        "return_url": ""
      });
      var jsonResponse;
      var url = Uri.parse("${constant.baseUrl}/gateway/initialize");
      var response = await http.post(url,
          body: data,
          headers: getGlobalHeader(
              xApiKey, "$merchandUserName:$merchandPassword", mode));
      jsonResponse = json.decode(response.body);
      if (response.statusCode == 200 || response.statusCode == 201) {
        print("This is /initiatePayment response : $jsonResponse");
        if (jsonResponse != null) {
          List result = await getAllProviders(
            context: context,
            transactionId: jsonResponse['data']['t_id'],
            transactionAmount: jsonResponse['data']['t_sum'],
            transactionCallBackUrl: jsonResponse['data']['t_url'],
            merchandPassword: merchandPassword,
            merchandUserName: merchandUserName,
            xApiKey: xApiKey,
            mode: mode,
            actionAfterProccess: actionAfterProccess,
          );
          Navigator.of(context).pop();

          return {"result": result, "transaction_id": transactionId};
        }
      } else {
        Navigator.of(context).pop();
        print("Response : $jsonResponse");
        if (jsonResponse['message'] == null) {
          constant.makeToast(jsonResponse['error'], context, Colors.red);
        } else {
          constant.makeToast(jsonResponse['message'], context, Colors.red);
        }
        actionAfterProccess(transactionId, "FAILED");
        return false;
      }
    } catch (e) {
      print("Error : $e");
      Navigator.of(context).pop();
      showInfoDialog(
          context, "Something went wrong , please try again or later");
      actionAfterProccess(transactionId, "FAILED");

      return false;
    }
  }

  getAllProviders({
    context,
    required String transactionId,
    required String transactionAmount,
    required String transactionCallBackUrl,
    required String merchandUserName,
    required String merchandPassword,
    required String xApiKey,
    required String mode,
    required Function actionAfterProccess,
  }) async {
    try {
      var jsonResponse;
      var url = Uri.parse(
          "${constant.baseUrl}/gateway/gateways?t_id=$transactionId&t_sum=$transactionAmount&t_url=$transactionCallBackUrl");
      var response = await http.get(url,
          headers: getGlobalHeader(
              xApiKey, "$merchandUserName:$merchandPassword", mode));
      jsonResponse = json.decode(response.body);
      if (response.statusCode == 200) {
        print("This is /getAllProviders response : $jsonResponse");
        if (jsonResponse != null) {
          return json.decode(response.body)['data'];
        }
      } else {
        if (jsonResponse != null) {
          print("Response :  : $jsonResponse");
          Navigator.of(context).pop();
          actionAfterProccess(transactionId, "FAILED");
          return [];
        }
      }
    } catch (e) {
      print("Error : $e");
      Navigator.of(context).pop();
      actionAfterProccess(transactionId, "FAILED");
      showInfoDialog(
          context, "Something went wrong , please try again or later");
    }
  }

  makePayment({
    required context,
    required String xApiKey,
    required String transactionAmount,
    required String transactionCallBackUrl,
    required String provider_short_tag,
    required String? phoneNumber,
    required Function actionAfterProccess,
    required String userName,
    required merchandUserName,
    required transaction_id,
    required merchandPassword,
    required mode,
    required currency,
    required paymentType,
  }) async {
    var response;
    var data = currency != null
        ? jsonEncode({
      'gateway': provider_short_tag,
      'amount': int.parse(transactionAmount),
      'transaction_id': transaction_id,
      'return_url': transactionCallBackUrl,
      'phone_number': phoneNumber,
      "name": userName,
      "currency": currency,
      "paymentType": paymentType
    })
        : jsonEncode({
      'gateway': provider_short_tag,
      'amount': int.parse(transactionAmount),
      'transaction_id': transaction_id,
      'return_url': transactionCallBackUrl,
      'phone_number': phoneNumber,
      "name": userName,
      "paymentType": paymentType
    });
    try {
      progressHub("Please wait", context);
      print("##A");

      var jsonResponse;
      var url = Uri.parse("${constant.baseUrl}/gateway/makepayment");
      response = await http.post(url,
          body: data,
          headers: getGlobalHeader(
              xApiKey, "$merchandUserName:$merchandPassword", mode));
      print("## ${response.body}");

      if (response.statusCode == 200 || response.statusCode == 201) {
        constant.makeToast(json.decode(response.body)['message'], context, Colors.green);
        jsonResponse = json.decode(response.body)["data"];
        if (jsonResponse["access_token"] != null) {
          print("Response #1 : $jsonResponse");
          String orderId = jsonResponse["order_id"];
          Map obj = {
            "order_id": orderId,
            "amount": jsonResponse["amount"],
            "currency": jsonResponse["currency"],
            "client_id": jsonResponse["client_id"],
            "accessToken": jsonResponse["access_token"],
          };
          Navigator.pop(context);
          return obj;
        } else {
          print("Response #2 : $jsonResponse");
          var obj = {
            "order_id": jsonResponse["order_id"],
            "amount": jsonResponse["amount"],
            "currency": jsonResponse["currency"],
            "client_id": jsonResponse["client_id"],
          };
          getPaymentStatus(
              transactionId: transaction_id,
              paymentRef: jsonResponse["payment_ref"],
              payToken: jsonResponse["pay_token"],
              merchandUserName: merchandUserName,
              merchandPassword: merchandPassword,
              provider_short_tag: provider_short_tag,
              actionAfterProccess: actionAfterProccess,
              context: context,
              mode: mode,
              xApiKey: xApiKey);
          return obj;
        }
      } else {
        var responseData = json.decode(response.body);
        Navigator.of(context).pop();
        actionAfterProccess(transaction_id, "FAILED");
        if (responseData != null) {
          payUnitStream.paymentSink.addError("Error");
          Navigator.of(context).pop();
          constant.makeToast(responseData['message'], context, Colors.red);
        }
      }
    } catch (e) {
      Navigator.of(context).pop();
      Navigator.of(context).pop();
      actionAfterProccess(transaction_id, "FAILED");
    }
  }

  getPaymentStatus({
    required context,
    required String transactionId,
    required String paymentRef,
    required String payToken,
    required String merchandUserName,
    required String merchandPassword,
    required String provider_short_tag,
    required Function actionAfterProccess,
    required String xApiKey,
    required String mode,
  }) async {
    try {
      const time = const Duration(seconds: 4);
      Timer.periodic(time, (Timer timer) async {
        var jsonResponse;
        var url = Uri.parse(
            "${constant.baseUrl}/gateway/paymentstatus/$provider_short_tag/$transactionId?payment_ref=${paymentRef}&pay_token=${payToken}");
        log(url.toString());
        var response = await http.get(url,
            headers: getGlobalHeader(
                xApiKey, "$merchandUserName:$merchandPassword", mode));
        print("This is response status/; ${response.statusCode}");
        print("This is response Mode/; $mode");
        jsonResponse = await jsonDecode(response.body);
        print("This is response status/; $jsonResponse");

        if (jsonResponse['status'] == "SUCCESSFUL") {
          print("Response SUCCESSFUL: $jsonResponse");
          Navigator.pop(context);
          actionAfterProccess(transactionId, "SUCCESS");
          timer.cancel();
        }

        if (jsonResponse['status'] == "FAILED") {
          Navigator.pop(context);
          print("Response FAILED: $jsonResponse");
          actionAfterProccess(transactionId, "FAILED");
          timer.cancel();
        }
      });
    } catch (e) {
      // Navigator.pop(context);
      actionAfterProccess(transactionId, "FAILED");
      showInfoDialog(
          context, "Something went wrong , please try again or later");
    }
  }

  progressHub(msg, context) {
    showDialog(
      barrierDismissible: false,
      barrierColor: Colors.black.withOpacity(0.5),
      context: context,
      builder: (context) => WillPopScope(
        onWillPop: () async {
          return false;
        },
        child: AlertDialog(
          shape:
          RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
          backgroundColor: Colors.white.withOpacity(0.9),
          content: SizedBox(
            height: 200.0,
            child: SpinKitSquareCircle(
              color: payUnitGreenColor,
              size: 50.0,
            ),
          ),
        ),
      ),
    );
  }

  closeDialog(context) {
    // NativeProgressHud.hideWaiting();
    Navigator.of(context).pop();
    // Navigator.of(context).pop();
  }
}
